summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoDocument.h')
-rw-r--r--lib/kofficecore/KoDocument.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index 4947506d..cb4f9f25 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -114,7 +114,7 @@ public:
/**
* Returns the action described action object. In fact only the "name" attribute
* of @p element is of interest here. The method searches first in the
* KActionCollection of the first view and then in the KActionCollection of this
* document.
* This allows %KOffice applications to define actions in both the view and the document.
* They should only define view-actions (like zooming and stuff) in the view.
@@ -126,7 +126,7 @@ public:
* @see KXMLGUIClient::actionCollection
* @see KoView::action
*/
- virtual KAction *action( const TQDomElement &element ) const;
+ virtual TDEAction *action( const TQDomElement &element ) const;
/**
* Returns the DOM document which describes the GUI of the
@@ -114,7 +114,7 @@ public:
* Returns the action described action object. In fact only the "name" attribute
* of @p element is of interest here. The method searches first in the
- * KActionCollection of the first view and then in the KActionCollection of this
+ * TDEActionCollection of the first view and then in the TDEActionCollection of this
* document.
* This allows %KOffice applications to define actions in both the view and the document.